@@ -28,3 +28,5 @@ ec = apc.e.gauss.value
 ideal_gas_const = apc.R.cgs.value
 # define year in CGS units
 year = 31557600.0
+# Hubble constant
+H0 = 70e5/(1e6*pc)
